@@ -52,7 +52,7 @@ dibble <- function(...,
                           x
                         }
                       })
-  args <- vec_c(!!!args)
+  args <- list_unchop(args)
 
   if (!is_named(args)) {
     stopifnot(
@@ -236,15 +236,18 @@ aperm_dibble <- function(a, perm, ...) {
     }
   }
 
+  class <- class(a)
   if (is_ddf_col(a)) {
     a <- aperm(as.array(a), perm, ...)
-    new_ddf_col(a, new_dim_names)
+    new_ddf_col(a, new_dim_names,
+                class = class)
   } else {
     a <- purrr::modify(undibble(a),
                        function(x) {
                          aperm(x, perm, ...)
                        })
-    new_tbl_ddf(a, new_dim_names)
+    new_tbl_ddf(a, new_dim_names,
+                class = class)
   }
 }
 
@@ -280,17 +283,20 @@ slice_dibble <- function(.data, ...) {
                            })
   names(dim_names) <- axes
 
+  class <- class(.data)
   if (is_ddf_col(.data)) {
     new_ddf_col(exec(`[`, .data, !!!locs,
                      drop = FALSE),
-                dim_names = dim_names)
+                dim_names = dim_names,
+                class = class)
   } else if (is_tbl_ddf(.data)) {
     new_tbl_ddf(purrr::modify(undibble(.data),
                               function(x) {
                                 exec(`[`, x, !!!locs,
                                      drop = FALSE)
                               }),
-                dim_names = dim_names)
+                dim_names = dim_names,
+                class = class)
   }
 }
 
@@ -393,9 +399,10 @@ find_index <- function(x, names) {
   } else {
     stopifnot(is_call(x))
 
-    out <- purrr::map(x[-1L], find_index,
-                      names = names)
-    vec_c(!!!out)
+    out <- purrr::map(as.list(x[-1L]),
+                      \(x) find_index(x,
+                                      names = names))
+    list_unchop(out)
   }
 }
 
@@ -415,6 +422,23 @@ head_symbol <- function(x) {
 # Printing ----------------------------------------------------------------
 
 print_dibble <- function(x, n, ...) {
+  writeLines(format(x, n = n, ...))
+  invisible(x)
+}
+
+format_dibble <- function(x, n, ...) {
+  n <- get_n_print(n, nrow(x))
+
+  setup <- tbl_format_setup(x,
+                            n = n,
+                            ...)
+  header <- tbl_format_header(x, setup)
+  body <- tbl_format_body(x, setup)
+  footer <- tbl_format_footer(x, setup)
+  c(header, body, footer)
+}
+
+tbl_format_setup_dibble <- function(x, n, ...) {
   dim_names <- dimnames(x)
   axes <- names(dim_names)
   dim <- list_sizes_unnamed(dim_names)
@@ -423,32 +447,46 @@ print_dibble <- function(x, n, ...) {
   meas_names <- colnames(x)
   size_meas <- big_mark(vec_size(meas_names))
 
-  df <- new_data_frame(as_tibble(head_dibble(x, n)),
-                       class = c("tbl_dibble", "tbl"))
-
   dim_sum <- c(`Dimensions` = commas(paste0(axes, " [", big_mark(dim), "]")))
-
   if (is_ddf_col(x)) {
-    attr(df, "tbl_sum") <- c(`A dibble` = big_mark(size_dim),
+    tbl_sum <- c(`A dibble` = big_mark(size_dim),
                              dim_sum)
   } else {
     tbl_sum <- c(`A dibble` = paste(big_mark(size_dim), size_meas,
                                     sep = " x "),
                  dim_sum,
                  `Measures` = commas(meas_names))
-
-    attr(df, "tbl_sum") <- tbl_sum
   }
 
-  attr(df, "rows_total") <- size_dim
-  print(df)
+  x <- tibble::as_tibble(head_dibble(x,
+                                     n = n))
+  setup <- tbl_format_setup(x,
+                            n = n,
+                            ...)
+  setup$tbl_sum <- tbl_sum
+  rows_total_old <- setup$rows_total
+  rows_total_new <- size_dim
+  setup$rows_total <- rows_total_new
+  setup$rows_missing <- setup$rows_missing + rows_total_new - rows_total_old
+  setup
+}
 
-  invisible(x)
+tbl_format_header_dibble <- function(x, setup, ...) {
+  x <- setup$x
+  tbl_format_header(x, setup, ...)
+}
+
+tbl_format_body_dibble <- function(x, setup, ...) {
+  x <- setup$x
+  tbl_format_body(x, setup, ...)
+}
+
+tbl_format_footer_dibble <- function(x, setup, ...) {
+  x <- setup$x
+  tbl_format_footer(x, setup, ...)
 }
 
 head_dibble <- function(x, n) {
-  # pillar:::get_pillar_option_print_max() + 1
-  n <- n %||% 21
   dim <- rev(dim(x))
 
   loc <- rep(1, vec_size(dim))
@@ -464,17 +502,3 @@ head_dibble <- function(x, n) {
 
   slice(x, !!!loc)
 }
-
-#' @importFrom pillar tbl_format_setup
-#' @export
-tbl_format_setup.tbl_dibble <- function(x, width, ..., n, max_extra_cols, max_footer_lines) {
-  setup <- NextMethod()
-
-  setup$tbl_sum <-  attr(x, "tbl_sum")
-
-  rows_total_old <- setup$rows_total
-  rows_total_new <- attr(x, "rows_total")
-  setup$rows_total <- rows_total_new
-  setup$rows_missing <- rows_total_new - (rows_total_old - setup$rows_missing)
-  setup
-}
