@@ -1,4 +1,4 @@
-.onLoad <- function(...) {
+.onLoad <- function(...) { # nocov start
   as_dim_names <<- memoise::memoise(as_dim_names)
   union_dim_names <<- memoise::memoise(union_dim_names)
   broadcast_dim_names_impl <<- memoise::memoise(broadcast_dim_names_impl)
@@ -9,7 +9,10 @@
   registerS3method("Ops", "ddf_col", Ops_dibble)
   registerS3method("Ops", "tbl_ddf", Ops_dibble)
 
+  registerS3method("matrixOps", "ddf_col", matrixOps_dibble)
+  registerS3method("matrixOps", "tbl_ddf", matrixOps_dibble)
+
   registerS3method("Math", "tbl_ddf", methods_dibble)
 
   registerS3method("Summary", "tbl_ddf", methods_dibble)
-}
+} # nocov end
